@@ -204,7 +204,11 @@ utils::globalVariables(
     "pair1",
     "W",
     "stat",
-    "contrast"
+    "contrast",
+    "chi2",
+    "comparisons",
+    "z.value",
+    "altp"
   ),
   package = "pairwiseComparisons",
   add = FALSE
